gantt chart ,  a class for showing a gantt chart quickly !

    chart = ganttChart()
    chart.addTask("User", 1234567.11334, 1234600.11334, "Step1/resource1", "orange")
    chart.addTask("User", 1234600.11334, 1234700.11334, "Step2/resource2", "green")
    chart.show()